##  Step 2: Commit the Manifest File
Establish a link with your microservice fact sheet in SAP LeanIX by committing the manifest file to the default branch of your repository, such as main or master.
**Note**
You can link multiple microservices to microservice fact sheets in SAP LeanIX from the same repository by placing the manifest files in separate subfolders within your repository structure. This approach is especially useful for monorepos.
